@@ -1,14 +1,11 @@
 # -*- coding: utf-8 -*-
 import unittest
-from convertdate.positivist import (
-    EPOCH, from_jd, to_jd, from_gregorian,
-    to_gregorian, legal_date, dayname, festival
-)
+
 from convertdate.data import positivist as data
+from convertdate.positivist import EPOCH, dayname, festival, from_gregorian, from_jd, legal_date, to_gregorian, to_jd
 
 
 class TestGregorian(unittest.TestCase):
-
     def setUp(self):
         pass
 
@@ -94,8 +91,4 @@ class TestGregorian(unittest.TestCase):
 
     def test_festival(self):
         self.assertIsNone(festival(1, 2))
-        self.assertEqual(festival(1, 1), data.festivals.get((1, 1)))
-
-
-if __name__ == '__main__':
-    unittest.main()
+        self.assertEqual(festival(1, 1), data.FESTIVALS.get((1, 1)))
