@@ -5,13 +5,11 @@ from convertdate import utils
 
 
 class TestConvertdate(unittest.TestCase):
-    def testCeil(self):
-        self.assertEqual(utils.ceil(1.2), math.ceil(1.2))
-        self.assertEqual(utils.ceil(-1.2), math.ceil(-1.2))
-
-    def testTruncFloor(self):
-        self.assertEqual(math.trunc(1.2), math.floor(1.2))
-        self.assertNotEqual(math.trunc(-1.2), math.floor(-1.2))
+    def test_amod(self):
+        self.assertEqual(utils.amod(10, 5), 5)
+        self.assertEqual(utils.amod(12, 3), 3)
+        self.assertEqual(utils.amod(12, 4), 4)
+        self.assertEqual(utils.amod(100, 4), 4)
 
     def test_jwday(self):
         self.assertEqual(utils.jwday(2459252.5), 6)
